#!/bin/sh
#
# mm2vym.sh
#
VERSION="0.1"
# Date: 20051119
# Author: Clemens Kraus
#


unpacker()
# Unpack mmap-file, only if it is one
{
  echo $MMAPFILE_EXT | grep -F ".mmap" 1>/dev/null

  if [ $? = 0 ] ; then
	  echo ">> Unpacking files in directory \"$MMAPXMLPATH\""
	  unzip -o $MMAPFILE_EXT -d $MMAPXMLPATH 1>/dev/null
	  if [ $? -gt 0 ] ; then
		echo ">>> Error in unzip! Aborting."
	  	exit 4
	  fi
  fi
}


packer()
# pack vym-file
{
  echo ">> Packing files ..."
  	zip $MMAPFILE.vym $MMAPFILE.xml
}


transform()
{
  echo ">> Starting XSLT transformation ..."
# Save original xml-file
#  cp $MMFILE_EXT $MMFILE"_tmp"
#  sabcmd mm2vym.xsl $mmfile \$filename=$vymfile > $mmfile".vym"
  xsltproc -o $MMAPFILE.xml --stringparam filenamep "$MMAPFILE" `dirname $MMAPFILE_PATH`/mm2vym.xsl $MMAPXMLFILE
  
	if [ $? -gt 0 ] ; then
		echo ">>> Error in xsltproc! Aborting."
		exit 2
	fi
}


remove_files()
# remove all temporary-files
{
  if [ -n "$MMAPXMLPATH" ] ; then
		echo ">> Removing temporary files ..."
		rm -rf $MMAPXMLPATH 2>/dev/null
  fi
	rm $MMAPFILE.xml 2>/dev/null
}


# -------------------- Parameter check -----------------------

USAGE="USAGE: $0 'mmfile.mmap' [Options]\n\n"
USAGE=$USAGE"mm2vym.sh converts MindManager X5/6 files to vym-format\n"
USAGE=$USAGE"Output:\tmmfile.vym\n\n"
USAGE=$USAGE"Options:\n"
USAGE=$USAGE"-v: prints the version of mm2vym\n"
USAGE=$USAGE"-help: shows this help\n"

if [ "$1" = '-v' ]; then
  echo "mm2vym Version: "$VERSION
  exit 0
fi
if [ "$1" = '-h' ]; then
	echo -e $USAGE
	exit 1
fi
if [ $# -lt 1 -o $# -gt 1 -o "$1" = '-h' ]; then 
	echo -e $USAGE
	exit 1
else
	MMAPFILE_EXT=$1
	MMAPFILE=`echo $MMAPFILE_EXT | cut -d. -f1`
	MMAPFILE_PATH=`dirname $MMAPFILE_EXT`
	MMAPXMLPATH=`basename $MMAPFILE`
	MMAPXMLFILE=$MMAPXMLPATH/Document.xml
fi


# ---------------------- Los geht's --------------------------
echo ">> Processing file '$MMAPFILE' ..."

# unpack
unpacker

# Transform
transform

# pack vym-file
packer

# clean up
remove_files

echo ">> Ready!"
echo ">> ---------------------"

exit 0


